@@ -1,13 +1,10 @@
-use crate::{
-    store::{PortMap, Store},
-    svec,
-};
+use crate::{docker::PortMap, store::Store, svec};
 
 pub struct MySQL;
 
 impl Store for MySQL {
     fn name(&self) -> String {
-        "oomplay-mysql".to_string()
+        "mysql".to_string()
     }
 
     fn image(&self) -> String {
@@ -22,7 +19,7 @@ impl Store for MySQL {
         vec![PortMap::Tcp(3306, 23306)]
     }
 
-    fn init_cmd(&self) -> Vec<String> {
+    fn reset_cmd(&self) -> Vec<String> {
         svec![
             "mysql",
             "-e",
