@@ -1,19 +1,35 @@
-#[allow(dead_code)]
-pub enum PortMap {
-    Tcp(u16, u16),
-    Udp(u16, u16),
-}
+use crate::docker::{Mount, PortMap};
 
 pub trait Store {
     fn name(&self) -> String;
-    fn image(&self) -> String;
-    fn port_map(&self) -> Vec<PortMap>;
-    fn ping_cmd(&self) -> Vec<String>;
-    fn init_cmd(&self) -> Vec<String>;
-    fn entry_cmd(&self) -> Option<Vec<String>> {
-        None
+
+    fn full_name(&self) -> String {
+        format!("oomplay-{}", self.name())
     }
+
+    fn image(&self) -> String;
+
+    fn network(&self) -> String {
+        "bridge".to_string()
+    }
+
+    fn port_map(&self) -> Vec<PortMap> {
+        Vec::new()
+    }
+
+    fn mounts(&self) -> Vec<Mount> {
+        Vec::new()
+    }
+
     fn envs(&self) -> Vec<String> {
         Vec::new()
     }
+
+    fn entry_cmd(&self) -> Option<Vec<String>> {
+        None
+    }
+
+    fn ping_cmd(&self) -> Vec<String>;
+
+    fn reset_cmd(&self) -> Vec<String>;
 }
